@@ -1,5 +1,5 @@
 package App::cpanminus;
-our $VERSION = "0.999_01";
+our $VERSION = "0.999_02";
 
 =head1 NAME
 
@@ -182,7 +182,7 @@ cpanminus at a boot time checks whether you have configured local::lib, or have
 the permission to install modules to the sitelib directory.  If neither, it
 automatically sets up local::lib compatible installation path in a C<perl5>
 directory under your home directory. To avoid this, run the script as the root
-user or with C<--sudo> option.
+user, with C<--sudo> option or with C<--local-lib> option.
 
 This L<local::lib> automatic integration is still considered alpha and
 in the work -- more bootstrapping is under development. Stay tuned.
@@ -218,14 +218,6 @@ some specific version of toolchain for configuration.
 
 =item *
 
-Distributions that test a SIGNATURE in the C<*.t> unit tests and has
-C<MANIFEST.SKIP> file in the distribution at the same time. The intent of
-signature testing is to provide some degree of security, but running it in unit
-tests is too late as it occurs I<after> running C<Makefile.PL>.  cpanminus has
-a C<verify_signature> plugin to verify the dist before configurations.
-
-=item *
-
 Distributions that have a C<META.yml> file that is encoded in YAML 1.1 format
 using L<YAML::XS>. This will be eventually solved once we move to C<META.json>.
 
